@@ -28,9 +28,9 @@ view needs to pull default settings from the main plugin config
 #include "katefiletreeproxymodel.h"
 
 #include <KColorButton>
-#include <KComboBox>
 #include <KLocalizedString>
 #include <QCheckBox>
+#include <QComboBox>
 #include <QGroupBox>
 #include <QLabel>
 #include <QVBoxLayout>
@@ -65,7 +65,7 @@ KateFileTreeConfigPage::KateFileTreeConfigPage(QWidget *parent, KateFileTreePlug
     layout->addLayout(lo2);
     lSort = new QLabel(i18n("&Sort by:"), this);
     lo2->addWidget(lSort);
-    cmbSort = new KComboBox(this);
+    cmbSort = new QComboBox(this);
     lo2->addWidget(cmbSort);
     lSort->setBuddy(cmbSort);
     cmbSort->addItem(i18n("Opening Order"), static_cast<int>(KateFileTreeModel::OpeningOrderRole));
@@ -77,7 +77,7 @@ KateFileTreeConfigPage::KateFileTreeConfigPage(QWidget *parent, KateFileTreePlug
     layout->addLayout(lo3);
     lMode = new QLabel(i18n("&View Mode:"), this);
     lo3->addWidget(lMode);
-    cmbMode = new KComboBox(this);
+    cmbMode = new QComboBox(this);
     lo3->addWidget(cmbMode);
     lMode->setBuddy(cmbMode);
     cmbMode->addItem(i18n("Tree View"), QVariant(false));
@@ -89,6 +89,15 @@ KateFileTreeConfigPage::KateFileTreeConfigPage(QWidget *parent, KateFileTreePlug
     cbShowFullPath = new QCheckBox(i18n("&Show Full Path"), this);
     lo4->addWidget(cbShowFullPath);
 
+    QHBoxLayout *lo5 = new QHBoxLayout;
+    layout->addLayout(lo5);
+    cbShowToolbar = new QCheckBox(i18n("Show &Toolbar"), this);
+    lo5->addWidget(cbShowToolbar);
+
+    cbShowClose = new QCheckBox(i18n("Show Close Button"), this);
+    layout->addWidget(cbShowClose);
+    layout->addWidget(new QLabel(i18n("When enabled, this will show a close button for opened documents on hover.")));
+
     layout->insertStretch(-1, 10);
 
     gbEnableShading->setWhatsThis(
@@ -105,6 +114,9 @@ KateFileTreeConfigPage::KateFileTreeConfigPage(QWidget *parent, KateFileTreePlug
         i18n("When enabled, in tree mode, top level folders will show up with their full path "
              "rather than just the last folder name."));
 
+    cbShowToolbar->setWhatsThis(
+        i18n("When enabled, a toolbar with actions like “Save” are displayed above the list of documents."));
+
     //   cmbSort->setWhatsThis( i18n(
     //       "Set the sorting method for the documents.") );
 
@@ -113,9 +125,11 @@ KateFileTreeConfigPage::KateFileTreeConfigPage(QWidget *parent, KateFileTreePlug
     connect(gbEnableShading, &QGroupBox::toggled, this, &KateFileTreeConfigPage::slotMyChanged);
     connect(kcbViewShade, &KColorButton::changed, this, &KateFileTreeConfigPage::slotMyChanged);
     connect(kcbEditShade, &KColorButton::changed, this, &KateFileTreeConfigPage::slotMyChanged);
-    connect(cmbSort, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &KateFileTreeConfigPage::slotMyChanged);
-    connect(cmbMode, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &KateFileTreeConfigPage::slotMyChanged);
+    connect(cmbSort, QOverload<int>::of(&QComboBox::activated), this, &KateFileTreeConfigPage::slotMyChanged);
+    connect(cmbMode, QOverload<int>::of(&QComboBox::activated), this, &KateFileTreeConfigPage::slotMyChanged);
     connect(cbShowFullPath, &QCheckBox::stateChanged, this, &KateFileTreeConfigPage::slotMyChanged);
+    connect(cbShowToolbar, &QCheckBox::stateChanged, this, &KateFileTreeConfigPage::slotMyChanged);
+    connect(cbShowClose, &QCheckBox::stateChanged, this, &KateFileTreeConfigPage::slotMyChanged);
 }
 
 QString KateFileTreeConfigPage::name() const
@@ -142,8 +156,14 @@ void KateFileTreeConfigPage::apply()
     m_changed = false;
 
     // apply config to views
-    m_plug->applyConfig(
-        gbEnableShading->isChecked(), kcbViewShade->color(), kcbEditShade->color(), cmbMode->itemData(cmbMode->currentIndex()).toBool(), cmbSort->itemData(cmbSort->currentIndex()).toInt(), cbShowFullPath->checkState() == Qt::Checked);
+    m_plug->applyConfig(gbEnableShading->isChecked(),
+                        kcbViewShade->color(),
+                        kcbEditShade->color(),
+                        cmbMode->itemData(cmbMode->currentIndex()).toBool(),
+                        cmbSort->itemData(cmbSort->currentIndex()).toInt(),
+                        cbShowFullPath->checkState() == Qt::Checked,
+                        cbShowToolbar->checkState() == Qt::Checked,
+                        cbShowClose->isChecked());
 }
 
 void KateFileTreeConfigPage::reset()
@@ -156,6 +176,8 @@ void KateFileTreeConfigPage::reset()
     cmbSort->setCurrentIndex(cmbSort->findData(settings.sortRole()));
     cmbMode->setCurrentIndex(settings.listMode());
     cbShowFullPath->setCheckState(settings.showFullPathOnRoots() ? Qt::Checked : Qt::Unchecked);
+    cbShowToolbar->setCheckState(settings.showToolbar() ? Qt::Checked : Qt::Unchecked);
+    cbShowClose->setChecked(settings.showCloseButton());
 
     m_changed = false;
 }
@@ -170,5 +192,5 @@ void KateFileTreeConfigPage::defaults()
 void KateFileTreeConfigPage::slotMyChanged()
 {
     m_changed = true;
-    emit changed();
+    Q_EMIT changed();
 }
