@@ -28,7 +28,8 @@ OutputStyleWidget::OutputStyleWidget(QWidget *parent)
 
     QStringList headerLabels;
 
-    headerLabels << i18nc("@title:column", "Context") << QString() << QString() << QString() << QString() << i18nc("@title:column", "Text Color") << i18nc("@title:column", "Background Color");
+    headerLabels << i18nc("@title:column", "Context") << QString() << QString() << QString() << QString() << i18nc("@title:column", "Text Color")
+                 << i18nc("@title:column", "Background Color");
 
     setHeaderLabels(headerLabels);
 
@@ -44,8 +45,9 @@ OutputStyleWidget::OutputStyleWidget(QWidget *parent)
     addContext(QStringLiteral("null"), i18nc("@item:intable", "NULL"));
     addContext(QStringLiteral("blob"), i18nc("@item:intable", "BLOB"));
 
-    for (int i = 0; i < columnCount(); ++i)
+    for (int i = 0; i < columnCount(); ++i) {
         resizeColumnToContents(i);
+    }
 
     updatePreviews();
 }
@@ -144,8 +146,9 @@ void OutputStyleWidget::readConfig()
 {
     QTreeWidgetItem *root = invisibleRootItem();
 
-    for (int i = 0; i < root->childCount(); ++i)
+    for (int i = 0; i < root->childCount(); ++i) {
         readConfig(root->child(i));
+    }
 }
 
 void OutputStyleWidget::writeConfig()
@@ -155,8 +158,9 @@ void OutputStyleWidget::writeConfig()
 
     QTreeWidgetItem *root = invisibleRootItem();
 
-    for (int i = 0; i < root->childCount(); ++i)
+    for (int i = 0; i < root->childCount(); ++i) {
         writeConfig(root->child(i));
+    }
 }
 
 void OutputStyleWidget::updatePreviews()
@@ -190,5 +194,5 @@ void OutputStyleWidget::slotChanged()
 {
     updatePreviews();
 
-    emit changed();
+    Q_EMIT changed();
 }
