@@ -1,5 +1,4 @@
-/*  SPDX-License-Identifier: MIT
-
+/*
     SPDX-FileCopyrightText: 2019 Mark Nauwelaerts <mark.nauwelaerts@gmail.com>
 
     SPDX-License-Identifier: MIT
@@ -16,6 +15,8 @@
 #include <QUrl>
 #include <QVector>
 
+#include "lspsemantichighlighting.h"
+
 #include <KTextEditor/Cursor>
 #include <KTextEditor/Range>
 
@@ -42,7 +43,7 @@ enum class LSPErrorCode {
 };
 
 struct LSPResponseError {
-    LSPErrorCode code {};
+    LSPErrorCode code{};
     QString message;
     QJsonValue data;
 };
@@ -66,7 +67,7 @@ struct LSPDocumentOnTypeFormattingOptions : public LSPSignatureHelpOptions {
 
 struct LSPSemanticHighlightingOptions {
     // cf. https://manual.macromates.com/en/language_grammars
-    QVector<QVector<QString>> scopes;
+    SemanticHighlighting scopes;
 };
 
 struct LSPServerCapabilities {
@@ -78,6 +79,7 @@ struct LSPServerCapabilities {
     // FIXME ? clangd unofficial extension
     bool declarationProvider = false;
     bool referencesProvider = false;
+    bool implementationProvider = false;
     bool documentSymbolProvider = false;
     bool documentHighlightProvider = false;
     bool documentFormattingProvider = false;
