@@ -1,5 +1,4 @@
-/*  SPDX-License-Identifier: MIT
-
+/*
     SPDX-FileCopyrightText: 2019 Mark Nauwelaerts <mark.nauwelaerts@gmail.com>
 
     SPDX-License-Identifier: MIT
@@ -64,7 +63,7 @@ public:
     {
         if (server) {
             auto root = server->root().toLocalFile();
-            return QStringLiteral("%1@%2").arg(server->langId()).arg(root);
+            return QStringLiteral("%1@%2").arg(server->langId(), root);
         } else {
             return {};
         }
