@@ -8,8 +8,10 @@
 #include "kateprojectinfoviewterminal.h"
 #include "kateprojectpluginview.h"
 
+#include <KConfigGroup>
 #include <KLocalizedString>
 #include <KPluginLoader>
+#include <KSharedConfig>
 #include <kde_terminal_interface.h>
 
 KPluginFactory *KateProjectInfoViewTerminal::s_pluginFactory = nullptr;
@@ -96,7 +98,9 @@ void KateProjectInfoViewTerminal::loadTerminal()
      * guard destruction, create new terminal!
      */
     connect(m_konsolePart, &KParts::ReadOnlyPart::destroyed, this, &KateProjectInfoViewTerminal::loadTerminal);
-    connect(m_konsolePart, SIGNAL(overrideShortcut(QKeyEvent *, bool &)), this, SLOT(overrideShortcut(QKeyEvent *, bool &)));
+    // clang-format off
+    connect(m_konsolePart, SIGNAL(overrideShortcut(QKeyEvent*,bool&)), this, SLOT(overrideShortcut(QKeyEvent*,bool&)));
+    // clang-format on
 }
 
 void KateProjectInfoViewTerminal::overrideShortcut(QKeyEvent *, bool &override)
@@ -106,3 +110,17 @@ void KateProjectInfoViewTerminal::overrideShortcut(QKeyEvent *, bool &override)
      */
     override = true;
 }
+
+// share with konsole plugin
+static const QStringList s_escapeExceptions{QStringLiteral("vi"), QStringLiteral("vim"), QStringLiteral("nvim")};
+
+bool KateProjectInfoViewTerminal::ignoreEsc() const
+{
+    if (!m_konsolePart || !KConfigGroup(KSharedConfig::openConfig(), "Konsole").readEntry("KonsoleEscKeyBehaviour", true)) {
+        return false;
+    }
+
+    const QStringList exceptList = KConfigGroup(KSharedConfig::openConfig(), "Konsole").readEntry("KonsoleEscKeyExceptions", s_escapeExceptions);
+    const auto app = qobject_cast<TerminalInterface *>(m_konsolePart)->foregroundProcessName();
+    return exceptList.contains(app);
+}
