@@ -14,12 +14,15 @@
 #include "kateprojectview.h"
 
 #include <QComboBox>
+#include <QMenu>
 #include <QPointer>
 #include <QStackedWidget>
 #include <QToolButton>
 
 #include <KXMLGUIClient>
 
+#include <memory>
+
 class QAction;
 
 class KateProjectPluginView : public QObject, public KXMLGUIClient
@@ -98,6 +101,38 @@ public:
         return m_plugin;
     }
 
+    /**
+     * @brief Shows diff in a fixed view, i.e., the view is recycled instead
+     * of creating new view every time
+     * @param contents diff contents
+     */
+    void showDiffInFixedView(const QByteArray &contents)
+    {
+        if (!m_fixedView.view) {
+            m_fixedView.view = mainWindow()->openUrl(QUrl());
+            m_fixedView.defaultMenu = m_fixedView.view->contextMenu();
+        }
+
+        m_fixedView.view->document()->setText(QString::fromUtf8(contents));
+        m_fixedView.view->document()->setHighlightingMode(QStringLiteral("Diff"));
+        /** We don't want save dialog on close */
+        m_fixedView.view->document()->setModified(false);
+        m_fixedView.restoreMenu();
+    }
+
+    /**
+     * Same as above with call back for setting a context menu
+     *
+     * @param cb Callback on the view. This should always take KTextEditor::View*
+     * as a parameter. This is mainly used to plug-in context-menu actions.
+     */
+    template<typename ViewCallback>
+    void showDiffInFixedView(const QByteArray &contents, ViewCallback cb)
+    {
+        showDiffInFixedView(contents);
+        cb(m_fixedView.view);
+    }
+
 public Q_SLOTS:
     /**
      * Create views for given project.
@@ -107,6 +142,12 @@ public Q_SLOTS:
      */
     QPair<KateProjectView *, KateProjectInfoView *> viewForProject(KateProject *project);
 
+    /**
+     * Switch to project for given dir, if any there!
+     * @param dir dir with the project
+     */
+    void switchToProject(const QDir &dir);
+
 private Q_SLOTS:
     /**
      * Plugin config updated
@@ -174,6 +215,13 @@ Q_SIGNALS:
      */
     void gotoSymbol(const QString &word, int &results);
 
+    /**
+     * Signal for outgoing message, the host application will handle them!
+     * Will only be handled inside the main windows of this plugin view.
+     * @param message outgoing message we send to the host application
+     */
+    void message(const QVariantMap &message);
+
 private Q_SLOTS:
     /**
      * This slot is called whenever the active view changes in our main window.
@@ -196,6 +244,21 @@ private Q_SLOTS:
      */
     void slotContextMenuAboutToShow();
 
+    /**
+     * Handle esc key and hide the toolview
+     */
+    void handleEsc(QEvent *e);
+
+    /**
+     * Update git status on toolview shown
+     */
+    void slotUpdateStatus(bool visible);
+
+    /**
+     * Open a folder / project
+     */
+    void openDirectoryOrProject();
+
 private:
     /**
      * find current selected or under cursor word
@@ -223,6 +286,11 @@ private:
      */
     QWidget *m_toolInfoView;
 
+    /**
+     * our projects info toolview
+     */
+    std::unique_ptr<QWidget> m_gitToolView;
+
     /**
      * our cross-projects toolview
      */
@@ -233,11 +301,21 @@ private:
      */
     QComboBox *m_projectsCombo;
 
+    /**
+     * combo box with all loaded projects inside
+     */
+    QComboBox *m_projectsComboGit;
+
     /**
      * Reload button
      */
     QToolButton *m_reloadButton;
 
+    /**
+     * Git status refresh button
+     */
+    QToolButton *m_gitStatusRefreshButton;
+
     /**
      * stacked widget will all currently created project views
      */
@@ -248,6 +326,11 @@ private:
      */
     QStackedWidget *m_stackedProjectInfoViews;
 
+    /**
+     * stacked widget will all currently created git views
+     */
+    QStackedWidget *m_stackedgitViews;
+
     /**
      * project => view
      */
@@ -274,6 +357,25 @@ private:
      */
     QAction *m_gotoSymbolAction;
     QAction *m_gotoSymbolActionAppMenu;
+
+    class FixedView
+    {
+    public:
+        QPointer<KTextEditor::View> view;
+        QPointer<QMenu> defaultMenu;
+
+        void restoreMenu()
+        {
+            if (view && defaultMenu) {
+                view->setContextMenu(defaultMenu);
+            }
+        }
+    };
+
+    /**
+     * Fixed view for viewing diffs
+     */
+    FixedView m_fixedView;
 };
 
 #endif
