@@ -11,9 +11,8 @@
 #include "kateproject.h"
 #include "kateprojectitem.h"
 
-#include <ThreadWeaver/Job>
-
-#include <QMap>
+#include <QHash>
+#include <QRunnable>
 #include <QStandardItemModel>
 
 class QDir;
@@ -22,7 +21,7 @@ class QDir;
  * Class representing a project background worker.
  * This worker will build up the model for the project on load and do other stuff in the background.
  */
-class KateProjectWorker : public QObject, public ThreadWeaver::Job
+class KateProjectWorker : public QObject, public QRunnable
 {
     Q_OBJECT
 
@@ -30,14 +29,16 @@ public:
     /**
      * Type for QueuedConnection
      */
-    typedef QMap<QString, KateProjectItem *> MapString2Item;
+    typedef QHash<QString, KateProjectItem *> MapString2Item;
 
     explicit KateProjectWorker(const QString &baseDir, const QString &indexDir, const QVariantMap &projectMap, bool force);
 
-    void run(ThreadWeaver::JobPointer self, ThreadWeaver::Thread *thread) override;
+    void run() override;
+
+    static QStandardItem *directoryParent(const QDir &base, QHash<QString, QStandardItem *> &dir2Item, QString path);
 
 Q_SIGNALS:
-    void loadDone(KateProjectSharedQStandardItem topLevel, KateProjectSharedQMapStringItem file2Item);
+    void loadDone(KateProjectSharedQStandardItem topLevel, KateProjectSharedQHashStringItem file2Item);
     void loadIndexDone(KateProjectSharedProjectIndex index);
 
 private:
@@ -48,7 +49,7 @@ private:
      * @param project variant map for this group
      * @param file2Item mapping file => item, will be filled
      */
-    void loadProject(QStandardItem *parent, const QVariantMap &project, QMap<QString, KateProjectItem *> *file2Item);
+    static void loadProject(QStandardItem *parent, const QVariantMap &project, QHash<QString, KateProjectItem *> *file2Item, const QString &baseDir);
 
     /**
      * Load one files entry in the current parent item.
@@ -56,23 +57,17 @@ private:
      * @param filesEntry one files entry specification to load
      * @param file2Item mapping file => item, will be filled
      */
-    void loadFilesEntry(QStandardItem *parent, const QVariantMap &filesEntry, QMap<QString, KateProjectItem *> *file2Item);
+    static void loadFilesEntry(QStandardItem *parent, const QVariantMap &filesEntry, QHash<QString, KateProjectItem *> *file2Item, const QString &baseDir);
 
-    /**
-     * Load index for whole project.
-     * @param files list of all project files to index
-     */
-    void loadIndex(const QStringList &files, bool force);
+    static QVector<QString> findFiles(const QDir &dir, const QVariantMap &filesEntry);
 
-    QStringList findFiles(const QDir &dir, const QVariantMap &filesEntry);
+    static QVector<QString> filesFromGit(const QDir &dir, bool recursive);
+    static QVector<QString> filesFromMercurial(const QDir &dir, bool recursive);
+    static QVector<QString> filesFromSubversion(const QDir &dir, bool recursive);
+    static QVector<QString> filesFromDarcs(const QDir &dir, bool recursive);
+    static QVector<QString> filesFromDirectory(const QDir &dir, bool recursive, const QStringList &filters);
 
-    QStringList filesFromGit(const QDir &dir, bool recursive);
-    QStringList filesFromMercurial(const QDir &dir, bool recursive);
-    QStringList filesFromSubversion(const QDir &dir, bool recursive);
-    QStringList filesFromDarcs(const QDir &dir, bool recursive);
-    QStringList filesFromDirectory(const QDir &dir, bool recursive, const QStringList &filters);
-
-    QStringList gitLsFiles(const QDir &dir);
+    static QVector<QString> gitFiles(const QDir &dir, bool recursive, const QStringList &args);
 
 private:
     /**
