@@ -1,19 +1,8 @@
-/*   Kate search plugin
- *
- * SPDX-FileCopyrightText: 2020 Kåre Särs <kare.sars@iki.fi>
- *
- * SPDX-License-Identifier: GPL-2.0-or-later
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program in a file called COPYING; if not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2020 Kåre Särs <kare.sars@iki.fi>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KateSearchCommand_h
 #define KateSearchCommand_h
@@ -33,6 +22,8 @@ class KateSearchCommand : public KTextEditor::Command
 public:
     KateSearchCommand(QObject *parent);
 
+    void setBusy(bool busy);
+
 Q_SIGNALS:
     void setSearchPlace(int place);
     void setCurrentFolder();
@@ -46,6 +37,9 @@ Q_SIGNALS:
 public:
     bool exec(KTextEditor::View *view, const QString &cmd, QString &msg, const KTextEditor::Range &range = KTextEditor::Range::invalid()) override;
     bool help(KTextEditor::View *view, const QString &cmd, QString &msg) override;
+
+private:
+    bool m_busy{false};
 };
 
 #endif
