@@ -106,7 +106,11 @@ PluginKateXMLCheckView::PluginKateXMLCheckView(KTextEditor::Plugin *plugin, KTex
     KXMLGUIClient::setComponentName(QStringLiteral("katexmlcheck"), i18n("Kate XML check")); // where i18n resources?
     setXMLFile(QStringLiteral("ui.rc"));
 
-    dock = m_mainWindow->createToolView(plugin, QStringLiteral("kate_plugin_xmlcheck_ouputview"), KTextEditor::MainWindow::Bottom, QIcon::fromTheme(QStringLiteral("misc")), i18n("XML Checker Output"));
+    dock = m_mainWindow->createToolView(plugin,
+                                        QStringLiteral("kate_plugin_xmlcheck_ouputview"),
+                                        KTextEditor::MainWindow::Bottom,
+                                        QIcon::fromTheme(QStringLiteral("misc")),
+                                        i18n("XML Checker Output"));
     listview = new QTreeWidget(dock);
     m_tmp_file = nullptr;
     QAction *a = actionCollection()->addAction(QStringLiteral("xml_check"));
@@ -261,8 +265,9 @@ void PluginKateXMLCheckView::slotClicked(QTreeWidgetItem *item, int column)
         uint column = item->text(2).toUInt(&ok);
         if (ok && ok2) {
             KTextEditor::View *kv = m_mainWindow->activeView();
-            if (!kv)
+            if (!kv) {
                 return;
+            }
 
             kv->setCursorPosition(KTextEditor::Cursor(line - 1, column));
         }
@@ -283,8 +288,9 @@ bool PluginKateXMLCheckView::slotValidate()
     m_dtdname = QLatin1String("");
 
     KTextEditor::View *kv = m_mainWindow->activeView();
-    if (!kv)
+    if (!kv) {
         return false;
+    }
     delete m_tmp_file;
     m_tmp_file = new QTemporaryFile();
     if (!m_tmp_file->open()) {
