@@ -74,16 +74,18 @@ private:
     void addEditorPages();
 
 private:
-    KateMainWindow * const m_mainWindow;
+    KateMainWindow *const m_mainWindow;
 
     bool m_dataChanged = false;
 
+    QComboBox *m_messageTypes;
     QCheckBox *m_modNotifications;
-    QComboBox *m_cmbQuickOpenMatchMode;
     QComboBox *m_cmbQuickOpenListMode;
     QSpinBox *m_tabLimit;
     QCheckBox *m_showTabCloseButton;
     QCheckBox *m_expandTabs;
+    QCheckBox *m_tabDoubleClickNewDocument;
+    QCheckBox *m_tabMiddleClickCloseDocument;
 
     Ui::SessionConfigWidget sessionConfigUi;
 
