@@ -37,6 +37,7 @@ public:
 
     bool openedByUser = false;
     bool openSuccess = true;
+    bool doPostLoadOperations = false;
 };
 
 class KateDocManager : public QObject
@@ -59,9 +60,11 @@ public:
         return m_docList;
     }
 
-    KTextEditor::Document *openUrl(const QUrl &, const QString &encoding = QString(), bool isTempFile = false, const KateDocumentInfo &docInfo = KateDocumentInfo());
+    KTextEditor::Document *
+    openUrl(const QUrl &, const QString &encoding = QString(), bool isTempFile = false, const KateDocumentInfo &docInfo = KateDocumentInfo());
 
-    QList<KTextEditor::Document *> openUrls(const QList<QUrl> &, const QString &encoding = QString(), bool isTempFile = false, const KateDocumentInfo &docInfo = KateDocumentInfo());
+    QList<KTextEditor::Document *>
+    openUrls(const QList<QUrl> &, const QString &encoding = QString(), bool isTempFile = false, const KateDocumentInfo &docInfo = KateDocumentInfo());
 
     bool closeDocument(KTextEditor::Document *, bool closeUrl = true);
     bool closeDocuments(const QList<KTextEditor::Document *> &documents, bool closeUrl = true);
@@ -145,20 +148,6 @@ Q_SIGNALS:
      */
     void documentDeleted(KTextEditor::Document *document);
 
-    /**
-     * This signal is emitted before the batch of documents is being created.
-     *
-     * You can use it to pause some updates.
-     */
-    void aboutToCreateDocuments();
-
-    /**
-     * This signal is emitted after the batch of documents is created.
-     *
-     * @param documents list of documents that have been created
-     */
-    void documentsCreated(const QList<KTextEditor::Document *> &documents);
-
     /**
      * This signal is emitted before the documents batch is going to be deleted
      *
