@@ -112,7 +112,7 @@ void KateViewManager::setupActions()
     m_splitViewVert = m_mainWindow->actionCollection()->addAction(QStringLiteral("view_split_vert"));
     m_splitViewVert->setIcon(QIcon::fromTheme(QStringLiteral("view-split-left-right")));
     m_splitViewVert->setText(i18n("Split Ve&rtical"));
-    m_mainWindow->actionCollection()->setDefaultShortcut(m_splitViewVert, Qt::CTRL + Qt::SHIFT + Qt::Key_L);
+    m_mainWindow->actionCollection()->setDefaultShortcut(m_splitViewVert, Qt::CTRL | Qt::SHIFT | Qt::Key_L);
     connect(m_splitViewVert, &QAction::triggered, this, &KateViewManager::slotSplitViewSpaceVert);
 
     m_splitViewVert->setWhatsThis(i18n("Split the currently active view vertically into two views."));
@@ -120,7 +120,7 @@ void KateViewManager::setupActions()
     m_splitViewHoriz = m_mainWindow->actionCollection()->addAction(QStringLiteral("view_split_horiz"));
     m_splitViewHoriz->setIcon(QIcon::fromTheme(QStringLiteral("view-split-top-bottom")));
     m_splitViewHoriz->setText(i18n("Split &Horizontal"));
-    m_mainWindow->actionCollection()->setDefaultShortcut(m_splitViewHoriz, Qt::CTRL + Qt::SHIFT + Qt::Key_T);
+    m_mainWindow->actionCollection()->setDefaultShortcut(m_splitViewHoriz, Qt::CTRL | Qt::SHIFT | Qt::Key_T);
     connect(m_splitViewHoriz, &QAction::triggered, this, &KateViewManager::slotSplitViewSpaceHoriz);
 
     m_splitViewHoriz->setWhatsThis(i18n("Split the currently active view horizontally into two views."));
@@ -128,7 +128,7 @@ void KateViewManager::setupActions()
     m_closeView = m_mainWindow->actionCollection()->addAction(QStringLiteral("view_close_current_space"));
     m_closeView->setIcon(QIcon::fromTheme(QStringLiteral("view-close")));
     m_closeView->setText(i18n("Cl&ose Current View"));
-    m_mainWindow->actionCollection()->setDefaultShortcut(m_closeView, Qt::CTRL + Qt::SHIFT + Qt::Key_R);
+    m_mainWindow->actionCollection()->setDefaultShortcut(m_closeView, Qt::CTRL | Qt::SHIFT | Qt::Key_R);
     connect(m_closeView, &QAction::triggered, this, &KateViewManager::slotCloseCurrentViewSpace, Qt::QueuedConnection);
 
     m_closeView->setWhatsThis(i18n("Close the currently active split view"));
@@ -163,7 +163,7 @@ void KateViewManager::setupActions()
 
     goPrev = m_mainWindow->actionCollection()->addAction(QStringLiteral("go_prev_split_view"));
     goPrev->setText(i18n("Previous Split View"));
-    m_mainWindow->actionCollection()->setDefaultShortcut(goPrev, Qt::SHIFT + Qt::Key_F8);
+    m_mainWindow->actionCollection()->setDefaultShortcut(goPrev, Qt::SHIFT | Qt::Key_F8);
     connect(goPrev, &QAction::triggered, this, &KateViewManager::activatePrevView);
 
     goPrev->setWhatsThis(i18n("Make the previous split view the active one."));
@@ -240,8 +240,10 @@ void KateViewManager::slotDocumentOpen()
         }
     }
     if (!fileListWithTooLargeFiles.isEmpty()) {
-        const QString text = i18n("<p>You are attempting to open one or more large files:</p><ul>%1</ul><p>Do you want to proceed?</p><p><strong>Beware that kate may stop responding for some time when opening large files.</strong></p>",
-                                  fileListWithTooLargeFiles);
+        const QString text = i18n(
+            "<p>You are attempting to open one or more large files:</p><ul>%1</ul><p>Do you want to proceed?</p><p><strong>Beware that kate may stop "
+            "responding for some time when opening large files.</strong></p>",
+            fileListWithTooLargeFiles);
         const auto ret = KMessageBox::warningYesNo(this, text, i18n("Opening Large File"), KStandardGuiItem::cont(), KStandardGuiItem::stop());
         if (ret == KMessageBox::No) {
             return;
@@ -429,6 +431,27 @@ KTextEditor::View *KateViewManager::createView(KTextEditor::Document *doc, KateV
      */
     KTextEditor::View *view = (vs ? vs : activeViewSpace())->createView(doc);
 
+    /**
+     * connect to signal here so we can handle post-load
+     * set cursor position for this view if we need to
+     */
+    KateDocumentInfo *docInfo = KateApp::self()->documentManager()->documentInfo(doc);
+    if (docInfo->doPostLoadOperations) {
+        docInfo->doPostLoadOperations = false; // do this only once
+
+        QSharedPointer<QMetaObject::Connection> conn(new QMetaObject::Connection());
+        auto handler = [view, conn](KTextEditor::Document *doc) {
+            disconnect(*conn);
+            if (doc->url().hasQuery()) {
+                KateApp::self()->setCursorFromQueryString(view);
+            } else {
+                KateApp::self()->setCursorFromArgs(view);
+            }
+        };
+
+        *conn = connect(doc, &KTextEditor::Document::textChanged, view, handler);
+    }
+
     /**
      * remember this view, active == false, min age set
      * create activity resource
@@ -445,7 +468,9 @@ KTextEditor::View *KateViewManager::createView(KTextEditor::Document *doc, KateV
     delete view->actionCollection()->action(QStringLiteral("set_confdlg"));
     delete view->actionCollection()->action(QStringLiteral("editor_options"));
 
-    connect(view, SIGNAL(dropEventPass(QDropEvent *)), mainWindow(), SLOT(slotDropEvent(QDropEvent *)));
+    // clang-format off
+    connect(view, SIGNAL(dropEventPass(QDropEvent*)), mainWindow(), SLOT(slotDropEvent(QDropEvent*)));
+    // clang-format on
     connect(view, &KTextEditor::View::focusIn, this, &KateViewManager::activateSpace);
 
     viewCreated(view);
@@ -548,6 +573,10 @@ void KateViewManager::setActiveSpace(KateViewSpace *vs)
     }
 
     vs->setActive(true);
+
+    // signal update history buttons in mainWindow
+    Q_EMIT historyBackEnabled(vs->isHistoryBackEnabled());
+    Q_EMIT historyForwardEnabled(vs->isHistoryForwardEnabled());
 }
 
 void KateViewManager::setActiveView(KTextEditor::View *view)
@@ -625,7 +654,7 @@ void KateViewManager::activateView(KTextEditor::View *view)
         // remember age of this view
         m_views[view].lruAge = m_minAge--;
 
-        emit viewChanged(view);
+        Q_EMIT viewChanged(view);
 
 #ifdef KF5Activities_FOUND
         // inform activity manager
@@ -729,7 +758,7 @@ void KateViewManager::closeView(KTextEditor::View *view)
             }
         }
 
-        emit viewChanged(newActiveView);
+        Q_EMIT viewChanged(newActiveView);
     }
 }
 
@@ -939,7 +968,7 @@ void KateViewManager::removeViewSpace(KateViewSpace *viewspace)
 
     updateViewSpaceActions();
 
-    emit viewChanged(v);
+    Q_EMIT viewChanged(v);
 }
 
 void KateViewManager::slotCloseOtherViews()
@@ -1082,8 +1111,9 @@ QString KateViewManager::saveSplitterConfig(QSplitter *s, KConfigBase *configBas
     const auto sizes = s->sizes();
     for (int it = 0; it < s->count(); ++it) {
         // skip empty sized invisible ones, if not last one, we need one thing at least
-        if ((sizes[it] == 0) && ((it + 1 < s->count()) || !childList.empty()))
+        if ((sizes[it] == 0) && ((it + 1 < s->count()) || !childList.empty())) {
             continue;
+        }
 
         // For KateViewSpaces, ask them to save the file list.
         auto obj = s->widget(it);
@@ -1103,8 +1133,9 @@ QString KateViewManager::saveSplitterConfig(QSplitter *s, KConfigBase *configBas
     }
 
     // if only one thing, skip splitter config export, if not top splitter
-    if ((s != this) && (childList.size() == 1))
+    if ((s != this) && (childList.size() == 1)) {
         return childList.at(0);
+    }
 
     // Save sizes, orient, children for this splitter
     KConfigGroup config(configBase, grp);
