@@ -57,9 +57,11 @@ public:
     /* restore it */
     void restoreViewConfiguration(const KConfigGroup &group);
 
-    KTextEditor::Document *openUrl(const QUrl &url, const QString &encoding, bool activate = true, bool isTempFile = false, const KateDocumentInfo &docInfo = KateDocumentInfo());
+    KTextEditor::Document *
+    openUrl(const QUrl &url, const QString &encoding, bool activate = true, bool isTempFile = false, const KateDocumentInfo &docInfo = KateDocumentInfo());
 
-    KTextEditor::Document *openUrls(const QList<QUrl> &url, const QString &encoding, bool isTempFile = false, const KateDocumentInfo &docInfo = KateDocumentInfo());
+    KTextEditor::Document *
+    openUrls(const QList<QUrl> &url, const QString &encoding, bool isTempFile = false, const KateDocumentInfo &docInfo = KateDocumentInfo());
 
     KTextEditor::View *openUrlWithView(const QUrl &url, const QString &encoding);
 
@@ -90,6 +92,9 @@ Q_SIGNALS:
     void viewChanged(KTextEditor::View *);
     void viewCreated(KTextEditor::View *);
 
+    void historyBackEnabled(bool e);
+    void historyForwardEnabled(bool e);
+
 public:
     /**
      * create and activate a new view for doc, if doc == 0, then
