@@ -47,6 +47,31 @@ KateViewSpace::KateViewSpace(KateViewManager *viewManager, QWidget *parent, cons
     hLayout->setSpacing(0);
     hLayout->setContentsMargins(0, 0, 0, 0);
 
+    // add left <-> right history buttons
+    m_historyBack = new QToolButton(this);
+    m_historyBack->setToolTip(i18n("Go Back"));
+    m_historyBack->setIcon(QIcon::fromTheme(QStringLiteral("arrow-left")));
+    m_historyBack->setAutoRaise(true);
+    KAcceleratorManager::setNoAccel(m_historyBack);
+    m_historyBack->installEventFilter(this); // on click, active this view space
+    hLayout->addWidget(m_historyBack);
+    connect(m_historyBack, &QToolButton::clicked, this, [this] {
+        goBack();
+    });
+    m_historyBack->setEnabled(false);
+
+    m_historyForward = new QToolButton(this);
+    m_historyForward->setIcon(QIcon::fromTheme(QStringLiteral("arrow-right")));
+    m_historyForward->setToolTip(i18n("Go Forward"));
+    m_historyForward->setAutoRaise(true);
+    KAcceleratorManager::setNoAccel(m_historyForward);
+    m_historyForward->installEventFilter(this); // on click, active this view space
+    hLayout->addWidget(m_historyForward);
+    connect(m_historyForward, &QToolButton::clicked, this, [this] {
+        goForward();
+    });
+    m_historyForward->setEnabled(false);
+
     // add tab bar
     m_tabBar = new KateTabBar(this);
     connect(m_tabBar, &KateTabBar::currentChanged, this, &KateViewSpace::changeView);
@@ -63,7 +88,7 @@ KateViewSpace::KateViewSpace(KateViewManager *viewManager, QWidget *parent, cons
     m_quickOpen->installEventFilter(this); // on click, active this view space
     hLayout->addWidget(m_quickOpen);
 
-    // forward tab bar quick open action to globa quick open action
+    // forward tab bar quick open action to global quick open action
     QAction *bridge = new QAction(QIcon::fromTheme(QStringLiteral("tab-duplicate")), i18nc("indicator for more documents", "+%1", 100), this);
     m_quickOpen->setDefaultAction(bridge);
     QAction *quickOpen = m_viewManager->mainWindow()->actionCollection()->action(QStringLiteral("view_quick_open"));
@@ -122,10 +147,11 @@ bool KateViewSpace::eventFilter(QObject *obj, QEvent *event)
     if (button == m_quickOpen && event->type() == QEvent::WhatsThis) {
         QHelpEvent *e = static_cast<QHelpEvent *>(event);
         const int hiddenDocs = hiddenDocuments();
-        QString helpText = (hiddenDocs == 0) ? i18n("Click here to switch to the Quick Open view.")
-                                             : i18np("Currently, there is one more document open. To see all open documents, switch to the Quick Open view by clicking here.",
-                                                     "Currently, there are %1 more documents open. To see all open documents, switch to the Quick Open view by clicking here.",
-                                                     hiddenDocs);
+        QString helpText = (hiddenDocs == 0)
+            ? i18n("Click here to switch to the Quick Open view.")
+            : i18np("Currently, there is one more document open. To see all open documents, switch to the Quick Open view by clicking here.",
+                    "Currently, there are %1 more documents open. To see all open documents, switch to the Quick Open view by clicking here.",
+                    hiddenDocs);
         QWhatsThis::showText(e->globalPos(), helpText, m_quickOpen);
         return true;
     }
@@ -151,6 +177,8 @@ void KateViewSpace::statusBarToggled()
 void KateViewSpace::tabBarToggled()
 {
     KateUpdateDisabler updatesDisabled(m_viewManager->mainWindow());
+    m_historyBack->setVisible(m_viewManager->mainWindow()->showTabBar());
+    m_historyForward->setVisible(m_viewManager->mainWindow()->showTabBar());
     m_tabBar->setVisible(m_viewManager->mainWindow()->showTabBar());
     m_split->setVisible(m_viewManager->mainWindow()->showTabBar());
     m_quickOpen->setVisible(m_viewManager->mainWindow()->showTabBar());
@@ -183,6 +211,11 @@ KTextEditor::View *KateViewSpace::createView(KTextEditor::Document *doc)
         }
     }
 
+    connect(v, &KTextEditor::View::cursorPositionChanged, this, [this](KTextEditor::View *view, const KTextEditor::Cursor &newPosition) {
+        if (view && view->document())
+            addJump(view->document()->url(), newPosition);
+    });
+
     // register document, it is shown below through showView() then
     registerDocument(doc);
 
@@ -441,6 +474,39 @@ void KateViewSpace::focusNextTab()
     }
 }
 
+void KateViewSpace::addJump(const QUrl &url, KTextEditor::Cursor c)
+{
+    // we are in the middle of jumps somewhere?
+    if (!m_locations.isEmpty() && currentLocation + 1 < m_locations.size()) {
+        // erase all forward history
+        m_locations.erase(m_locations.begin() + currentLocation + 1, m_locations.end());
+    }
+
+    // if same line, remove last entry
+    if (!m_locations.isEmpty() && m_locations.back().url == url && m_locations.back().cursor.line() == c.line()) {
+        m_locations.pop_back();
+    }
+
+    // limit size to 100, remove first 20
+    if (m_locations.size() >= 100) {
+        m_locations.erase(m_locations.begin(), m_locations.begin() + 20);
+    }
+
+    // this is our new forward
+
+    m_locations.push_back({url, c});
+    // set to last
+    currentLocation = m_locations.size() - 1;
+    // disable forward button as we are at the end now
+    m_historyForward->setEnabled(false);
+    Q_EMIT m_viewManager->historyForwardEnabled(false);
+
+    // renable back
+    if (currentLocation > 0) {
+        m_historyBack->setEnabled(true);
+        Q_EMIT m_viewManager->historyBackEnabled(true);
+    }
+}
 int KateViewSpace::hiddenDocuments() const
 {
     const int hiddenDocs = KateApp::self()->documents().count() - m_tabBar->count();
@@ -491,7 +557,9 @@ void KateViewSpace::showContextMenu(int idx, const QPoint &globalPos)
         mCompareWithActive->setEnabled(false);
     }
 
-    auto activeDocument = KTextEditor::Editor::instance()->application()->activeMainWindow()->activeView()->document(); // used for mCompareWithActive which is used with another tab which is not active
+    auto activeDocument =
+        KTextEditor::Editor::instance()->application()->activeMainWindow()->activeView()->document(); // used for mCompareWithActive which is used with another
+                                                                                                      // tab which is not active
     // both documents must have urls and must not be the same to have the compare feature enabled
     if (activeDocument->url().isEmpty() || activeDocument == doc) {
         mCompareWithActive->setEnabled(false);
@@ -527,7 +595,10 @@ void KateViewSpace::showContextMenu(int idx, const QPoint &globalPos)
     } else if (choice->parent() == mCompareWithActive) {
         QString actionData = choice->data().toString(); // name of the executable of the diff program
         if (!KateFileActions::compareWithExternalProgram(activeDocument, doc, actionData)) {
-            QMessageBox::information(this, i18n("Could not start program"), i18n("The selected program could not be started. Maybe it is not installed."), QMessageBox::StandardButton::Ok);
+            QMessageBox::information(this,
+                                     i18n("Could not start program"),
+                                     i18n("The selected program could not be started. Maybe it is not installed."),
+                                     QMessageBox::StandardButton::Ok);
         }
     }
 }
@@ -575,6 +646,15 @@ void KateViewSpace::restoreConfig(KateViewManager *viewMan, const KConfigBase *c
 {
     KConfigGroup group(config, groupname);
 
+    // workaround for the weird bug where the tabbar sometimes becomes invisible after opening a session via the session chooser dialog or the --start cmd
+    // option
+    // TODO: Debug the actual reason for the bug. See https://invent.kde.org/utilities/kate/-/merge_requests/189
+    m_tabBar->hide();
+    m_tabBar->show();
+
+    // set back bar status to configured variant
+    tabBarToggled();
+
     // restore Document lru list so that all tabs from the last session reappear
     const QStringList lruList = group.readEntry("Documents", QStringList());
     for (int i = 0; i < lruList.size(); ++i) {
@@ -596,7 +676,18 @@ void KateViewSpace::restoreConfig(KateViewManager *viewMan, const KConfigBase *c
 
             auto view = viewMan->createView(doc, this);
             if (view) {
-                view->readSessionConfig(configGroup);
+                // When a session is opened with a remote file being active, we need to wait
+                // with applying saved session settings until the remote's temp file is initialised.
+                if (!view->document()->url().isLocalFile()) {
+                    QSharedPointer<QMetaObject::Connection> conn(new QMetaObject::Connection());
+                    auto handler = [conn, view, configGroup](KTextEditor::Document *) {
+                        disconnect(*conn);
+                        view->readSessionConfig(configGroup);
+                    };
+                    *conn = connect(doc, &KTextEditor::Document::textChanged, view, handler);
+                } else {
+                    view->readSessionConfig(configGroup);
+                }
                 m_tabBar->setCurrentDocument(doc);
             }
         }
@@ -604,9 +695,97 @@ void KateViewSpace::restoreConfig(KateViewManager *viewMan, const KConfigBase *c
 
     // avoid empty view space
     if (m_docToView.isEmpty()) {
-        viewMan->createView(KateApp::self()->documentManager()->documentList().first(), this);
+        auto *doc = KateApp::self()->documentManager()->documentList().first();
+        if (!fn.isEmpty()) {
+            QUrl url(fn);
+            KateApp::self()->documentManager()->documentInfo(doc)->doPostLoadOperations =
+                !url.isLocalFile() && (KateApp::self()->hasCursorInArgs() || url.hasQuery());
+        }
+        viewMan->createView(doc, this);
     }
 
     m_group = groupname; // used for restroing view configs later
 }
+
+void KateViewSpace::goBack()
+{
+    if (m_locations.isEmpty() || currentLocation == 0) {
+        return;
+    }
+
+    const auto &location = m_locations.at(currentLocation - 1);
+    currentLocation--;
+
+    if (currentLocation <= 0) {
+        m_historyBack->setEnabled(false);
+        Q_EMIT m_viewManager->historyBackEnabled(false);
+    }
+
+    if (auto v = m_viewManager->activeView()) {
+        if (v->document() && v->document()->url() == location.url) {
+            const QSignalBlocker blocker(m_viewManager->activeView());
+            m_viewManager->activeView()->setCursorPosition(location.cursor);
+            // enable forward
+            m_historyForward->setEnabled(true);
+            Q_EMIT m_viewManager->historyForwardEnabled(true);
+            return;
+        }
+    }
+
+    auto v = m_viewManager->openUrlWithView(location.url, QString());
+    const QSignalBlocker blocker(v);
+    v->setCursorPosition(location.cursor);
+    // enable forward in viewspace + mainwindow
+    m_historyForward->setEnabled(true);
+    Q_EMIT m_viewManager->historyForwardEnabled(true);
+}
+
+bool KateViewSpace::isHistoryBackEnabled() const
+{
+    return m_historyBack->isEnabled();
+}
+
+bool KateViewSpace::isHistoryForwardEnabled() const
+{
+    return m_historyForward->isEnabled();
+}
+
+void KateViewSpace::goForward()
+{
+    if (m_locations.isEmpty()) {
+        return;
+    }
+    if (currentLocation == m_locations.size() - 1) {
+        return;
+    }
+
+    const auto &location = m_locations.at(currentLocation + 1);
+    currentLocation++;
+
+    if (currentLocation + 1 >= m_locations.size()) {
+        Q_EMIT m_viewManager->historyForwardEnabled(false);
+        m_historyForward->setEnabled(false);
+    }
+
+    if (!location.url.isValid() || !location.cursor.isValid()) {
+        m_locations.remove(currentLocation);
+        return;
+    }
+
+    m_historyBack->setEnabled(true);
+    Q_EMIT m_viewManager->historyBackEnabled(true);
+
+    if (auto v = m_viewManager->activeView()) {
+        if (v->document() && v->document()->url() == location.url) {
+            const QSignalBlocker blocker(m_viewManager->activeView());
+            m_viewManager->activeView()->setCursorPosition(location.cursor);
+            return;
+        }
+    }
+
+    auto v = m_viewManager->openUrlWithView(location.url, QString());
+    const QSignalBlocker blocker(v);
+    v->setCursorPosition(location.cursor);
+}
+
 // END KateViewSpace
