@@ -91,6 +91,26 @@ public:
      */
     void focusNextTab();
 
+    /**
+     * go forward in location history
+     */
+    void goForward();
+
+    /**
+     * go back in location history
+     */
+    void goBack();
+
+    /**
+     * Is back history avail?
+     */
+    bool isHistoryBackEnabled() const;
+
+    /**
+     * Is forward history avail?
+     */
+    bool isHistoryForwardEnabled() const;
+
 public Q_SLOTS:
     void documentDestroyed(QObject *doc);
     void updateDocumentName(KTextEditor::Document *doc);
@@ -136,6 +156,11 @@ private:
      */
     int hiddenDocuments() const;
 
+    /**
+     * Add a jump location for jumping back and forth between history
+     */
+    void addJump(const QUrl &url, KTextEditor::Cursor);
+
 private:
     // Kate's view manager
     KateViewManager *m_viewManager;
@@ -150,6 +175,15 @@ private:
     // widget stack that contains all KTE::Views
     QStackedWidget *stack;
 
+    // jump location history for this view-space
+    struct Location {
+        QUrl url;
+        KTextEditor::Cursor cursor;
+    };
+
+    QVector<Location> m_locations;
+    int currentLocation = 0;
+
     /**
      * all documents this view space is aware of
      * depending on the limit of tabs, not all will have a corresponding
@@ -171,6 +205,12 @@ private:
 
     // quick open action
     QToolButton *m_quickOpen;
+
+    // go back in history button (only visible when the tab bar is visible)
+    QToolButton *m_historyBack;
+
+    // go forward in history button (only visible when the tab bar is visible)
+    QToolButton *m_historyForward;
 };
 
 #endif
